"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PermissionOverrideService = void 0;
class PermissionOverrideService {
    constructor(httpRequest) {
        this.httpRequest = httpRequest;
    }
    /**
     * Create a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionCreate({ serverId, channelId, roleId, requestBody, }) {
        return this.httpRequest.request({
            method: "POST",
            url: "/servers/{serverId}/channels/{channelId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                roleId: roleId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Read a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionRead({ serverId, channelId, roleId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/channels/{channelId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                roleId: roleId,
            },
        });
    }
    /**
     * Update a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionUpdate({ serverId, channelId, roleId, requestBody, }) {
        return this.httpRequest.request({
            method: "PATCH",
            url: "/servers/{serverId}/channels/{channelId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                roleId: roleId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Delete a channel role permission
     * @returns void
     * @throws ApiError
     */
    channelRolePermissionDelete({ serverId, channelId, roleId, }) {
        return this.httpRequest.request({
            method: "DELETE",
            url: "/servers/{serverId}/channels/{channelId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                roleId: roleId,
            },
        });
    }
    /**
     * ReadMany a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionReadMany({ serverId, channelId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/channels/{channelId}/permissions/roles",
            path: {
                serverId: serverId,
                channelId: channelId,
            },
        });
    }
    /**
     * Create a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionCreate({ serverId, channelId, userId, requestBody, }) {
        return this.httpRequest.request({
            method: "POST",
            url: "/servers/{serverId}/channels/{channelId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                userId: userId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Read a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionRead({ serverId, channelId, userId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/channels/{channelId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                userId: userId,
            },
        });
    }
    /**
     * Update a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionUpdate({ serverId, channelId, userId, requestBody, }) {
        return this.httpRequest.request({
            method: "PATCH",
            url: "/servers/{serverId}/channels/{channelId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                userId: userId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Delete a channel user permission
     * @returns void
     * @throws ApiError
     */
    channelUserPermissionDelete({ serverId, channelId, userId, }) {
        return this.httpRequest.request({
            method: "DELETE",
            url: "/servers/{serverId}/channels/{channelId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                channelId: channelId,
                userId: userId,
            },
        });
    }
    /**
     * Read a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionReadMany({ serverId, channelId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/channels/{channelId}/permissions/users",
            path: {
                serverId: serverId,
                channelId: channelId,
            },
        });
    }
    /**
     * Create a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionCreate({ serverId, categoryId, userId, requestBody, }) {
        return this.httpRequest.request({
            method: "POST",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                userId: userId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Read a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionRead({ serverId, categoryId, userId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                userId: userId,
            },
        });
    }
    /**
     * Update a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionUpdate({ serverId, categoryId, userId, requestBody, }) {
        return this.httpRequest.request({
            method: "PATCH",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                userId: userId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Delete a channel category user permission
     * @returns void
     * @throws ApiError
     */
    channelCategoryUserPermissionDelete({ serverId, categoryId, userId, }) {
        return this.httpRequest.request({
            method: "DELETE",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/users/{userId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                userId: userId,
            },
        });
    }
    /**
     * Get a list of the channel category user permissions
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionReadMany({ serverId, categoryId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/users",
            path: {
                serverId: serverId,
                categoryId: categoryId,
            },
        });
    }
    /**
     * Create a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionCreate({ serverId, categoryId, roleId, requestBody, }) {
        return this.httpRequest.request({
            method: "POST",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                roleId: roleId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Read a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionRead({ serverId, categoryId, roleId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                roleId: roleId,
            },
        });
    }
    /**
     * Update a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionUpdate({ serverId, categoryId, roleId, requestBody, }) {
        return this.httpRequest.request({
            method: "PATCH",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                roleId: roleId,
            },
            body: requestBody,
            mediaType: "application/json",
        });
    }
    /**
     * Delete a channel category role permission
     * @returns void
     * @throws ApiError
     */
    channelCategoryRolePermissionDelete({ serverId, categoryId, roleId, }) {
        return this.httpRequest.request({
            method: "DELETE",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/roles/{roleId}",
            path: {
                serverId: serverId,
                categoryId: categoryId,
                roleId: roleId,
            },
        });
    }
    /**
     * Get a list of the channel category role permissions
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionReadMany({ serverId, categoryId, }) {
        return this.httpRequest.request({
            method: "GET",
            url: "/servers/{serverId}/categories/{categoryId}/permissions/roles",
            path: {
                serverId: serverId,
                categoryId: categoryId,
            },
        });
    }
}
exports.PermissionOverrideService = PermissionOverrideService;
//# sourceMappingURL=PermissionOverrideService.js.map