import type { ChatEmbed } from "./ChatEmbed";
import type { Mentions } from "./Mentions";
export type ChatMessage = {
    /**
     * The ID of the message
     */
    id: string;
    /**
     * The type of chat message. "system" messages are generated by Guilded, while "default" messages are user or bot-generated.
     */
    type: "default" | "system";
    /**
     * The ID of the server
     */
    serverId?: string;
    /**
     * The ID of the group
     */
    groupId?: string;
    /**
     * The ID of the channel
     */
    channelId: string;
    /**
     * The content of the message
     */
    content?: string;
    /**
     * Links in `content` to prevent unfurling as a link preview when displaying in Guilded
     */
    hiddenLinkPreviewUrls?: Array<string>;
    embeds?: Array<ChatEmbed>;
    /**
     * Message IDs that were replied to
     */
    replyMessageIds?: Array<string>;
    /**
     * If set, this message will only be seen by those mentioned or replied to
     */
    isPrivate?: boolean;
    /**
     * If set, this message did not notify mention or reply recipients
     */
    isSilent?: boolean;
    isPinned?: boolean;
    mentions?: Mentions;
    /**
     * The ISO 8601 timestamp that the message was created at
     */
    createdAt: string;
    /**
     * The ID of the user who created this message (Note: If this event has `createdByWebhookId` present, this field will still be populated, but can be ignored. In this case, the value of this field will always be Ann6LewA)
     */
    createdBy: string;
    /**
     * The ID of the webhook who created this message, if it was created by a webhook
     */
    createdByWebhookId?: string;
    /**
     * The ISO 8601 timestamp that the message was updated at, if relevant
     */
    updatedAt?: string;
};
//# sourceMappingURL=ChatMessage.d.ts.map