import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { Category } from "../models/Category";
export declare class CategoriesService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a category
     * @returns any Success
     * @throws ApiError
     */
    categoryCreate({ serverId, requestBody, }: {
        serverId: string;
        requestBody: {
            /**
             * Name of the category
             */
            name: string;
            /**
             * The ID of the group. If not provided, the category will be created in the "Server home" group from `serverId`.
             */
            groupId?: string;
        };
    }): CancelablePromise<{
        category: Category;
    }>;
    /**
     * Read a category
     * @returns any Success
     * @throws ApiError
     */
    categoryRead({ serverId, categoryId, }: {
        serverId: string;
        categoryId: number;
    }): CancelablePromise<{
        category: Category;
    }>;
    /**
     * Update a category
     * @returns any Success
     * @throws ApiError
     */
    categoryUpdate({ serverId, categoryId, requestBody, }: {
        serverId: string;
        categoryId: number;
        requestBody: {
            /**
             * Name of the category
             */
            name?: string;
            /**
             * The priority of the category will determine its position relative to other categories in the group. The higher the value, the higher up it will be displayed in the UI. Returned values can be null, in which case sorting will be done by `createdAt` in descending order. Due to legacy issues, sending a null value is not possible
             */
            priority?: number;
        };
    }): CancelablePromise<{
        category: Category;
    }>;
    /**
     * Delete a category
     * @returns any Success
     * @throws ApiError
     */
    categoryDelete({ serverId, categoryId, }: {
        serverId: string;
        categoryId: number;
    }): CancelablePromise<{
        category: Category;
    }>;
}
//# sourceMappingURL=CategoriesService.d.ts.map