import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { ForumTopicComment } from "../models/ForumTopicComment";
export declare class ForumCommentsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a forum topic comment
     * @returns any Success
     * @throws ApiError
     */
    forumTopicCommentCreate({ channelId, forumTopicId, requestBody, }: {
        channelId: string;
        forumTopicId: number;
        requestBody: {
            /**
             * The content of the forum topic comment
             */
            content: string;
        };
    }): CancelablePromise<{
        forumTopicComment: ForumTopicComment;
    }>;
    /**
     * Get a forum topic's comments
     * @returns any Success
     * @throws ApiError
     */
    forumTopicCommentReadMany({ channelId, forumTopicId, }: {
        channelId: string;
        forumTopicId: number;
    }): CancelablePromise<{
        forumTopicComments: Array<ForumTopicComment>;
    }>;
    /**
     * Get a comment on a forum topic
     * @returns any Success
     * @throws ApiError
     */
    forumTopicCommentRead({ channelId, forumTopicId, forumTopicCommentId, }: {
        channelId: string;
        forumTopicId: number;
        forumTopicCommentId: number;
    }): CancelablePromise<{
        forumTopicComment: ForumTopicComment;
    }>;
    /**
     * Update a forum topic comment
     * @returns any Success
     * @throws ApiError
     */
    forumTopicCommentUpdate({ channelId, forumTopicId, forumTopicCommentId, requestBody, }: {
        channelId: string;
        forumTopicId: number;
        forumTopicCommentId: number;
        requestBody: {
            /**
             * The content of the forum topic
             */
            content?: string;
        };
    }): CancelablePromise<{
        forumTopicComment: ForumTopicComment;
    }>;
    /**
     * Delete a forum topic comment
     * @returns void
     * @throws ApiError
     */
    forumTopicCommentDelete({ channelId, forumTopicId, forumTopicCommentId, }: {
        channelId: string;
        forumTopicId: number;
        forumTopicCommentId: number;
    }): CancelablePromise<void>;
}
//# sourceMappingURL=ForumCommentsService.d.ts.map