import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { ListItem } from "../models/ListItem";
import type { ListItemSummary } from "../models/ListItemSummary";
export declare class ListItemsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a list item
     * @returns any Success
     * @throws ApiError
     */
    listItemCreate({ channelId, requestBody, }: {
        channelId: string;
        requestBody: {
            /**
             * The message of the list item
             */
            message: Record<string, any> | string;
            note?: {
                /**
                 * The note of the list item
                 */
                content: Record<string, any> | string;
            };
        };
    }): CancelablePromise<{
        listItem: ListItem;
    }>;
    /**
     * Get list items within a channel
     * @returns any Success
     * @throws ApiError
     */
    listItemReadMany({ channelId, }: {
        channelId: string;
    }): CancelablePromise<{
        listItems: Array<ListItemSummary>;
    }>;
    /**
     * Get a list item
     * @returns any Success
     * @throws ApiError
     */
    listItemRead({ channelId, listItemId, }: {
        channelId: string;
        listItemId: string;
    }): CancelablePromise<{
        listItem: ListItem;
    }>;
    /**
     * Update a list item
     * @returns any Success
     * @throws ApiError
     */
    listItemUpdate({ channelId, listItemId, requestBody, }: {
        channelId: string;
        listItemId: string;
        requestBody: {
            /**
             * The message of the list item
             */
            message?: string;
            note?: {
                /**
                 * The note of the list item
                 */
                content: string;
            } | null;
        };
    }): CancelablePromise<{
        listItem: ListItem;
    }>;
    /**
     * Delete a list item
     * @returns void
     * @throws ApiError
     */
    listItemDelete({ channelId, listItemId, }: {
        channelId: string;
        listItemId: string;
    }): CancelablePromise<void>;
    /**
     * Complete a list item
     * @returns void
     * @throws ApiError
     */
    listItemCompleteCreate({ channelId, listItemId, }: {
        channelId: string;
        listItemId: string;
    }): CancelablePromise<void>;
    /**
     * Uncomplete a list item
     * @returns void
     * @throws ApiError
     */
    listItemCompleteDelete({ channelId, listItemId, }: {
        channelId: string;
        listItemId: string;
    }): CancelablePromise<void>;
}
//# sourceMappingURL=ListItemsService.d.ts.map