import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { ServerMember } from "../models/ServerMember";
import type { ServerMemberSummary } from "../models/ServerMemberSummary";
export declare class MembersService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Update a member's nickname
     * @returns any Success
     * @throws ApiError
     */
    memberNicknameUpdate({ serverId, userId, requestBody, }: {
        serverId: string;
        /**
         * The ID of the user to update nickname for
         */
        userId: string | "@me";
        requestBody: {
            /**
             * The nickname to assign to the member
             */
            nickname: string;
        };
    }): CancelablePromise<{
        /**
         * The nickname that was assigned to the member
         */
        nickname: string;
    }>;
    /**
     * Delete a member's nickname
     * @returns void
     * @throws ApiError
     */
    memberNicknameDelete({ serverId, userId, }: {
        serverId: string;
        /**
         * The ID of the user to remove nickname from
         */
        userId: string | "@me";
    }): CancelablePromise<void>;
    /**
     * Get a server member
     * @returns any Success
     * @throws ApiError
     */
    serverMemberRead({ serverId, userId, }: {
        serverId: string;
        userId: string | "@me";
    }): CancelablePromise<{
        member: ServerMember;
    }>;
    /**
     * Kick a server member
     * This route can be used to leave servers by passing in your own user ID or `@me` for `userId`
     * @returns void
     * @throws ApiError
     */
    serverMemberDelete({ serverId, userId, }: {
        /**
         * The ID of the server to kick the user from
         */
        serverId: string;
        /**
         * The ID of the user to kick. If the value provided here is your own user's ID, the request will attempt to make you leave the server
         */
        userId: string | "@me";
    }): CancelablePromise<void>;
    /**
     * Get members of a server
     * Results returned will be ordered ascending by the member's `joinedAt`
     * @returns any Success
     * @throws ApiError
     */
    serverMemberReadMany({ serverId, }: {
        serverId: string;
    }): CancelablePromise<{
        members: Array<ServerMemberSummary>;
    }>;
}
//# sourceMappingURL=MembersService.d.ts.map