import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
import type { ChannelCategoryRolePermission } from "../models/ChannelCategoryRolePermission";
import type { ChannelCategoryUserPermission } from "../models/ChannelCategoryUserPermission";
import type { ChannelRolePermission } from "../models/ChannelRolePermission";
import type { ChannelUserPermission } from "../models/ChannelUserPermission";
export declare class PermissionOverrideService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionCreate({ serverId, channelId, roleId, requestBody, }: {
        serverId: string;
        channelId: string;
        roleId: number;
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelRolePermission: ChannelRolePermission;
    }>;
    /**
     * Read a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionRead({ serverId, channelId, roleId, }: {
        serverId: string;
        channelId: string;
        roleId: number;
    }): CancelablePromise<{
        channelRolePermission: ChannelRolePermission;
    }>;
    /**
     * Update a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionUpdate({ serverId, channelId, roleId, requestBody, }: {
        serverId: string;
        channelId: string;
        roleId: number;
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelRolePermission: ChannelRolePermission;
    }>;
    /**
     * Delete a channel role permission
     * @returns void
     * @throws ApiError
     */
    channelRolePermissionDelete({ serverId, channelId, roleId, }: {
        serverId: string;
        channelId: string;
        roleId: number;
    }): CancelablePromise<void>;
    /**
     * ReadMany a channel role permission
     * @returns any Success
     * @throws ApiError
     */
    channelRolePermissionReadMany({ serverId, channelId, }: {
        serverId: string;
        channelId: string;
    }): CancelablePromise<{
        channelRolePermissions: Array<ChannelRolePermission>;
    }>;
    /**
     * Create a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionCreate({ serverId, channelId, userId, requestBody, }: {
        serverId: string;
        channelId: string;
        userId: string | "@me";
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelUserPermission: ChannelUserPermission;
    }>;
    /**
     * Read a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionRead({ serverId, channelId, userId, }: {
        serverId: string;
        channelId: string;
        userId: string | "@me";
    }): CancelablePromise<{
        channelUserPermission: ChannelUserPermission;
    }>;
    /**
     * Update a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionUpdate({ serverId, channelId, userId, requestBody, }: {
        serverId: string;
        channelId: string;
        userId: string | "@me";
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelUserPermission: ChannelUserPermission;
    }>;
    /**
     * Delete a channel user permission
     * @returns void
     * @throws ApiError
     */
    channelUserPermissionDelete({ serverId, channelId, userId, }: {
        serverId: string;
        channelId: string;
        userId: string | "@me";
    }): CancelablePromise<void>;
    /**
     * Read a channel user permission
     * @returns any Success
     * @throws ApiError
     */
    channelUserPermissionReadMany({ serverId, channelId, }: {
        serverId: string;
        channelId: string;
    }): CancelablePromise<{
        channelUserPermissions: Array<ChannelUserPermission>;
    }>;
    /**
     * Create a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionCreate({ serverId, categoryId, userId, requestBody, }: {
        serverId: string;
        categoryId: number;
        userId: string | "@me";
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelCategoryUserPermission: ChannelCategoryUserPermission;
    }>;
    /**
     * Read a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionRead({ serverId, categoryId, userId, }: {
        serverId: string;
        categoryId: number;
        userId: string | "@me";
    }): CancelablePromise<{
        channelCategoryUserPermission: ChannelCategoryUserPermission;
    }>;
    /**
     * Update a channel category user permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionUpdate({ serverId, categoryId, userId, requestBody, }: {
        serverId: string;
        categoryId: number;
        userId: string | "@me";
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelCategoryUserPermission: ChannelCategoryUserPermission;
    }>;
    /**
     * Delete a channel category user permission
     * @returns void
     * @throws ApiError
     */
    channelCategoryUserPermissionDelete({ serverId, categoryId, userId, }: {
        serverId: string;
        categoryId: number;
        userId: string | "@me";
    }): CancelablePromise<void>;
    /**
     * Get a list of the channel category user permissions
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryUserPermissionReadMany({ serverId, categoryId, }: {
        serverId: string;
        categoryId: number;
    }): CancelablePromise<{
        channelCategoryUserPermissions: Array<ChannelCategoryUserPermission>;
    }>;
    /**
     * Create a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionCreate({ serverId, categoryId, roleId, requestBody, }: {
        serverId: string;
        categoryId: number;
        roleId: number;
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelCategoryRolePermission: ChannelCategoryRolePermission;
    }>;
    /**
     * Read a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionRead({ serverId, categoryId, roleId, }: {
        serverId: string;
        categoryId: number;
        roleId: number;
    }): CancelablePromise<{
        channelCategoryRolePermission: ChannelCategoryRolePermission;
    }>;
    /**
     * Update a channel category role permission
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionUpdate({ serverId, categoryId, roleId, requestBody, }: {
        serverId: string;
        categoryId: number;
        roleId: number;
        requestBody: {
            /**
             * A JSON object of [Enums/Permissions](https://www.guilded.gg/docs/api/Permissions) with `true`, `false` or null values. Permission list can only contain relevant permissions for the channel type
             */
            permissions: Record<string, any>;
        };
    }): CancelablePromise<{
        channelCategoryRolePermission: ChannelCategoryRolePermission;
    }>;
    /**
     * Delete a channel category role permission
     * @returns void
     * @throws ApiError
     */
    channelCategoryRolePermissionDelete({ serverId, categoryId, roleId, }: {
        serverId: string;
        categoryId: number;
        roleId: number;
    }): CancelablePromise<void>;
    /**
     * Get a list of the channel category role permissions
     * @returns any Success
     * @throws ApiError
     */
    channelCategoryRolePermissionReadMany({ serverId, categoryId, }: {
        serverId: string;
        categoryId: number;
    }): CancelablePromise<{
        channelCategoryRolePermissions: Array<ChannelCategoryRolePermission>;
    }>;
}
//# sourceMappingURL=PermissionOverrideService.d.ts.map