import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
export declare class RoleMembershipService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Assign role to member
     * @returns void
     * @throws ApiError
     */
    roleMembershipCreate({ serverId, userId, roleId, }: {
        serverId: string;
        /**
         * The ID of the member that the role should be assigned to
         */
        userId: string | "@me";
        /**
         * The role ID to apply to the user
         */
        roleId: number;
    }): CancelablePromise<void>;
    /**
     * Remove role from member
     * @returns void
     * @throws ApiError
     */
    roleMembershipDelete({ serverId, userId, roleId, }: {
        serverId: string;
        /**
         * The ID of the member that the role should be removed from
         */
        userId: string | "@me";
        /**
         * The role ID to remove from the user
         */
        roleId: number;
    }): CancelablePromise<void>;
    /**
     * Get member roles
     * Get a list of the roles assigned to a member
     * @returns any Success
     * @throws ApiError
     */
    roleMembershipReadMany({ serverId, userId, }: {
        serverId: string;
        /**
         * The ID of the member to obtain roles from
         */
        userId: string | "@me";
    }): CancelablePromise<{
        /**
         * The IDs of the roles that the member currently has
         */
        roleIds: Array<number>;
    }>;
}
//# sourceMappingURL=RoleMembershipService.d.ts.map