import type { BaseHttpRequest } from "../core/BaseHttpRequest";
import type { CancelablePromise } from "../core/CancelablePromise";
export declare class ServerXpService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Award XP to a member
     * @returns any Success
     * @throws ApiError
     */
    serverXpForUserCreate({ serverId, userId, requestBody, }: {
        serverId: string;
        /**
         * Member ID to award XP to
         */
        userId: string | "@me";
        requestBody: {
            /**
             * The amount of XP to award
             */
            amount: number;
        };
    }): CancelablePromise<{
        /**
         * The total XP after this operation
         */
        total: number;
    }>;
    /**
     * Set a member's XP
     * @returns any Success
     * @throws ApiError
     */
    serverXpForUserUpdate({ serverId, userId, requestBody, }: {
        serverId: string;
        /**
         * Member ID to set XP to
         */
        userId: string | "@me";
        requestBody: {
            /**
             * The total XP to set on the user
             */
            total: number;
        };
    }): CancelablePromise<{
        /**
         * The total XP after this operation
         */
        total: number;
    }>;
    /**
     * Bulk award XP to members
     * Take note of the max number of `userIds` that can be submitted on each request. If you require more, please batch your requests
     * @returns any Success
     * @throws ApiError
     */
    serverXpForUserCreateMany({ serverId, requestBody, }: {
        serverId: string;
        requestBody: {
            /**
             * The amount of XP to award
             */
            amount: number;
            userIds: Array<string | "@me">;
        };
    }): CancelablePromise<{
        /**
         * Each key of the object will be a user ID, and its value will be the total for that user after this operation
         */
        totalsByUserId: Record<string, number>;
    }>;
    /**
     * Bulk set members' XP
     * Take note of the max number of `userIds` that can be submitted on each request. If you require more, please batch your requests
     * @returns any Success
     * @throws ApiError
     */
    serverXpForUserUpdateMany({ serverId, requestBody, }: {
        serverId: string;
        requestBody: {
            /**
             * The total XP to set on each user
             */
            amount: number;
            userIds: Array<string | "@me">;
        };
    }): CancelablePromise<{
        /**
         * Each key of the object will be a user ID, and its value will be the total for that user after this operation
         */
        totalsByUserId: Record<string, number>;
    }>;
    /**
     * Award XP to role
     * Award XP to all members with a particular role.
     * @returns void
     * @throws ApiError
     */
    serverXpForRoleCreate({ serverId, roleId, requestBody, }: {
        serverId: string;
        /**
         * Role ID to award XP to
         */
        roleId: number;
        requestBody: {
            /**
             * The amount of XP to award
             */
            amount: number;
        };
    }): CancelablePromise<void>;
}
//# sourceMappingURL=ServerXpService.d.ts.map